import argparse
import pysolarfocus as sf

from pymodbus.client.sync import ModbusTcpClient as ModbusClient


def run(host):
    client =  ModbusClient(host, port=502)
    #client.connect()

    rr = client.read_input_registers(1100, 7)
    print(f"Heizkreis: {rr.registers}")

    rr = client.read_input_registers(1900, 6)
    print(f"Puffer: {rr.registers}")

    rr = client.read_input_registers(500, 3)
    print(f"Boiler: {rr.registers}")

    rr = client.read_input_registers(2300, 31)
    print(f"Wärmepumpe: {rr.registers}")


    bits = (rr.registers[7] << 16) + rr.registers[8]

    bits_in_kwh=float(bits/1000)
   # s = struct.pack('>l', bits)
    #final = struct.unpack('>f', s)[0]
    print(f"Gesamt: {bits} Wh")
    print(f"Gesamt: {bits_in_kwh} kWh")

    rr = client.read_input_registers(2500, 10)
    print(f"PV: {rr.registers}")

    solarfocus = sf.SolarfocusAPI(client, 1)

    solarfocus.update()

    value=solarfocus.hc1_supply_temp
    print(f"vorlauf: {value}")


def main():
    #parser = argparse.ArgumentParser(description="Solarfocus Heating System")
    #parser.add_argument("--host", help="Local Solarfocus host (or IP)")
    #args = parser.parse_args()

    run( "172.16.1.17" )#args.host)


if __name__ == "__main__":
    main()


__version__ = '0.1.0'

from multiprocessing import Value

from .const import B1_REGMAP_INPUT, B1_START_ADDR


class SolarfocusAPI():
    """Solarfocus Heating System"""

    @property
    def hc1_supply_temp(self):
        """Supply temperature of heating circuit 1"""
        return self._block_1_input_regs.get('HC_1_SUPPLY_TEMPERATURE')['value'] * 0.01


    def __init__(self, conn, slave, update_on_read=False):
        """Initialize Solarfocus communication."""
        self._conn = conn
        self._block_1_input_regs = B1_REGMAP_INPUT
        self._slave = slave
        self._update_on_read = update_on_read

    def connect(self):
        return self._conn.connect()

    def update(self):
        """Read values from Heating System"""
        try:
            block_1_result_input = self._conn.read_input_registers(
                unit=self._slave,
                address=B1_START_ADDR,
                count=len(self._block_1_input_regs)).registers
        except AttributeError:
            # The unit does not reply reliably
            ret = False
            print("Modbus read failed")

        else:
            for k in self._block_1_input_regs:
                self._block_1_input_regs[k]['value'] = \
                    block_1_result_input[
                        self._block_1_input_regs[k]['addr'] - B1_START_ADDR]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pysolarfocus']

package_data = \
{'': ['*']}

install_requires = \
['pymodbus>=2.5.3,<3.0.0']

setup_kwargs = {
    'name': 'pysolarfocus',
    'version': '0.0.1',
    'description': 'Unofficial, local Solarfocus client',
    'long_description': '# pySolarfocus: Python Client for Solarfocus\n\nUnofficial local Solarfocus client for heatpump',
    'author': 'Jeroen Laverman',
    'author_email': 'jjlaverman@web.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lavermanjj/pysolarfocus',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
